<?php
/*
 * This file is part of Sylar.
 *
 * Sylar is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sylar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Sylar.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @copyright Copyright Sylar Development Team
 * @license http://www.gnu.org/licenses/ GNU Public License V2.0
 * @see https://launchpad.net/sylar/
 * @see http://www.giano-solutions.com
 */
 

import('sylar.presentation.Format');
import('sylar.presentation.html.HtmlPage');


 
/**
 * Main Format Class for Application
 * 
 * Main Class for formatting output in your Application. 
 * Every classes used to format page and html in your application must extend this class
 * 
 * @package Sylar
 * @version 1.0
 * @since 05/mar/08
 * 
 * @author Gianluca Giusti [brdp] <g.giusti@giano-solutions.com>
 * @copyright Sylar Development Team
 */
 
class App_Format extends Sylar_Format{
	
	function __construct(Sylar_LocaleConfiguration $localeConf=null){
		parent::__construct($localeConf);
	}
	function __destruct(){
		// nothing to do at the moment
	}
	
	
	
	
	//								 							  Public Methods
	//__________________________________________________________________________
	
	
	/**
	 * Return Head
	 * 
	 *
	 * @return Sylar_HtmlHead
	 * @param string $sTitle
	 */
	public function provideStandardHeader($sTitle=APP_HTML_TITLE){
		
		try {
			$oHH = new Sylar_HtmlHead($sTitle);	
			
			$oHH->addMetaTag("text/html; charset=".APP_DEFAULT_CHARSET, null, "content-type");
			$oHH->addMetaTag("Brdp - Giano Solutions", "Author");
			$oHH->addMetaTag("Sylar, Example App", "Keywords");		
			$oHH->addMetaTag("width=1024", "viewport");
			$oHH->addMetaTag("no-cache", null, "pragma");
			
			$oHH->setAppCssUrlRoot(APP_LAYOUT_CSS_URL_ROOT);
			$oHH->addApplicationStyle("mainGiano.css");
			
			$oHH->setAppJsUrlRoot(APP_JAVASCRIPT_URL_ROOT);
			$oHH->addApplicationJavascript("mainGiano.js");
			
			return $oHH;
			
		}catch (ExceptionInSylar $ex){
			throw $ex;
			return null;
		}
	}
	

}
 
 
?>